==> percona-xtrabackup-80_8.0.28-21.orig.tar.gz: percona-xtrabackup-8.0.28-21/unittest/gunit/into_syntax-t.cc <==
/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <gtest/gtest.h>

#include "unittest/gunit/parsertest.h"
#include "unittest/gunit/test_utils.h"

namespace into_syntax_unittest {

using my_testing::Mock_error_handler;
using my_testing::Server_initializer;

class IntoSyntaxTest : public ParserTest {};

TEST_F(IntoSyntaxTest, Outer) {
  Query_block *term = parse("SELECT 1 INTO @v");
  Query_expression *top_union = term->master_query_expression();
  EXPECT_EQ(nullptr, top_union->outer_query_block());
}

}  // namespace into_syntax_unittest

==> percona-xtrabackup-84_8.4.0-2.orig.tar.gz: percona-xtrabackup-8.4.0-2/unittest/gunit/into_syntax-t.cc <==
/* Copyright (c) 2015, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <gtest/gtest.h>

#include "unittest/gunit/parsertest.h"
#include "unittest/gunit/test_utils.h"

namespace into_syntax_unittest {

using my_testing::Mock_error_handler;
using my_testing::Server_initializer;

class IntoSyntaxTest : public ParserTest {};

TEST_F(IntoSyntaxTest, Outer) {
  Query_block *term = parse("SELECT 1 INTO @v");
  Query_expression *top_union = term->master_query_expression();
  EXPECT_EQ(nullptr, top_union->outer_query_block());
}

}  // namespace into_syntax_unittest
